@@ -46,7 +46,7 @@ class TimeRow(AbstractData):
     # level = copy.copy(stat)
     # scales = None
     # freqs = None
-    # X_q = None
+    X_q = None
     # centered_values = None
 
     def load(self, file_name=None, row=None, time=None):
